@@ -16,7 +16,7 @@
 
 import os
 import platform
-from subprocess import Popen, PIPE, STDOUT
+from subprocess import Popen, STDOUT
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common import utils
 import time
@@ -34,13 +34,16 @@ class FirefoxBinary(object):
          - firefox_path - Path to the Firefox executable. By default, it will be detected from the standard locations.
          - log_file - A file object to redirect the firefox process output to. It can be sys.stdout.
                       Please note that with parallel run the output won't be synchronous.
-                      By default, it will be redirected to subprocess.PIPE.
+                      By default, it will be redirected to /dev/null.
         """
         self._start_cmd = firefox_path
-        self._log_file = log_file or PIPE
+        self._log_file = log_file or open(os.devnull, "wb")
         self.command_line = None
         if self._start_cmd is None:
             self._start_cmd = self._get_firefox_start_cmd()
+        if not self._start_cmd.strip():
+          raise Exception("Failed to find firefox binary. You can set it by specifying the path to 'firefox_binary':\n\nfrom selenium.webdriver.firefox.firefox_binary import FirefoxBinary\n\n" +
+            "binary = FirefoxBinary('/path/to/binary')\ndriver = webdriver.Firefox(firefox_binary=binary)")
         # Rather than modifying the environment of the calling Python process
         # copy it and modify as needed.
         self._firefox_env = os.environ.copy()
@@ -109,9 +112,9 @@ class FirefoxBinary(object):
 
     def _find_exe_in_registry(self):
         try:
-            from _winreg import OpenKey, QueryValue, HKEY_LOCAL_MACHINE
+            from _winreg import OpenKey, QueryValue, HKEY_LOCAL_MACHINE, HKEY_CURRENT_USER
         except ImportError:
-            from winreg import OpenKey, QueryValue, HKEY_LOCAL_MACHINE
+            from winreg import OpenKey, QueryValue, HKEY_LOCAL_MACHINE, HKEY_CURRENT_USER
         import shlex
         keys = (
            r"SOFTWARE\Classes\FirefoxHTML\shell\open\command",
@@ -124,7 +127,12 @@ class FirefoxBinary(object):
                 command = QueryValue(key, "")
                 break
             except OSError:
-                pass
+                try:
+                    key = OpenKey(HKEY_CURRENT_USER, path)
+                    command = QueryValue(key, "")
+                    break
+                except OSError:
+                    pass
         else:
             return ""
 
