@@ -161,6 +161,8 @@ class ErrorHandler(object):
                 pass
         if exception_class == ErrorInResponseException:
             raise exception_class(response, message)
+        elif exception_class == UnexpectedAlertPresentException and 'alert' in value:
+            raise exception_class(message, screen, stacktrace, value['alert'].get('text'))
         raise exception_class(message, screen, stacktrace)
 
     def _value_or_default(self, obj, key, default):
